<template>
  <div class="bbsl-common-page">
    <el-row :gutter="10" class="search-row">
      <el-col :span="5">
        <div class="search-box">
          <div class="search-title">筛选类型</div>
          <el-select v-model="searchType" placeholder="请选择">
            <el-option v-for="item in typeOptions" :key="item.value" :label="item.label" :value="item.value">
            </el-option>
          </el-select>
        </div>
      </el-col>
      <el-col :span="4.5" v-if="searchType !== '3'">
        <div class="search-box">
          <div class="search-title">年份</div>
          <el-date-picker key="yearDate" v-model="yearValue" type="year" placeholder="选择年" value-format="yyyy">
          </el-date-picker>
        </div>
      </el-col>
      <el-col :span="4.5" v-if="searchType === '2'">
        <div class="search-box">
          <div class="search-title">季度</div>
          <el-select v-model="quarterValue" placeholder="请选择">
            <el-option v-for="item in quarterOptions" :key="item.value" :label="item.label" :value="item.date">
            </el-option>
          </el-select>
        </div>
      </el-col>

      <el-col :span="7" v-if="searchType === '3'">
        <div class="search-box">
          <div class="search-title">任意时间</div>
          <el-date-picker v-model="date" key="date" type="daterange" range-separator="至" start-placeholder="开始日期"
            end-placeholder="结束日期" value-format="yyyy-MM-dd" :popper-append-to-body="false">
          </el-date-picker>
        </div>
      </el-col>
      <el-col :span="4">
        <el-button style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="handleSearch">搜索
        </el-button>
        <el-button icon="el-icon-refresh" @click="handleReset">重置
        </el-button>
      </el-col>
    </el-row>
    <el-row :gutter="10">
      <el-col :span="8">
        <div class="module-box">
          <!-- 整体成本分析 -->
          <overall-cost :searchDate="searchDate"/>
        </div>
      </el-col>
      <el-col :span="16">
        <div class="module-box">
          <!-- 物资成本分析 -->
          <material-cost :searchDate="searchDate"/>
        </div>
      </el-col>
    </el-row>
    <el-row :gutter="10">
      <el-col :span="24">
        <div class="module-box">
          <!-- 部门物资成本分析 -->
          <departmental-material-cost :searchDate="searchDate"/>
        </div>
      </el-col>
      <!-- <el-col :span="12">
        <div class="module-box">

        </div>
      </el-col> -->
    </el-row>
    <el-row :gutter="10">
      <el-col :span="12">
        <div class="module-box">
          <!-- 物资库存统计 -->
          <material-inventory :searchDate="searchDate"/>
        </div>
      </el-col>
      <el-col :span="12">
        <div class="module-box">
          <!-- 部门物资统计 -->
          <departmental-material :searchDate="searchDate"/>
        </div>
      </el-col>
    </el-row>
  </div>
</template>

<script>
import overallCost from './graphs/overallCost'
import materialCost from './graphs/materialCost'
import departmentalMaterialCost from './graphs/departmentalMaterialCost'
import departmentalMaterial from './graphs/departmentalMaterial'
import materialInventory from './graphs/materialInventory'
export default {
  name: 'CMGTMaterialCostAnalysis',
  components: {
    overallCost,
    materialCost,
    departmentalMaterialCost,
    departmentalMaterial,
    materialInventory
  },
  data() {
    return {
      date: '',
      typeOptions: [
        {
          label: '年份',
          value: '1',
        },
        {
          label: '季度',
          value: '2'
        },
        {
          label: '任意时间',
          value: '3'
        }
      ],
      quarterOptions: [
        {
          label: '第一季度',
          value: '1',
          date: ['01-01', '03-31'],
        },
        {
          label: '第二季度',
          value: '2',
          date: ['04-01', '06-30'],
        },
        {
          label: '第三季度',
          value: '3',
          date: ['07-01', '09-30'],
        },
        {
          label: '第四季度',
          value: '4',
          date: ['10-01', '12-31'],
        }
      ],
      searchType: '1',
      yearValue: '',
      quarterValue: '',
      searchDate: {
        startDate: '',
        endDate: ''
      }
    }
  },
  mounted() {
  },
  methods: {
    handleSearch() {
      let { searchType, searchDate, yearValue, quarterValue, date } = this
      if (searchType === '1') {
        searchDate.startDate = yearValue ? yearValue + '-01-01' : ''
        searchDate.endDate = yearValue ? yearValue + '-12-31' : ''
      } else if (searchType === '2') {
        searchDate.startDate = yearValue+'-' + (quarterValue[0] || '01-01')
        searchDate.endDate = yearValue +'-'+ (quarterValue[1] || '12-31')
      } else {
        searchDate.startDate = date[0]
        searchDate.endDate = date[1]
      }
    },
    handleReset() {
      this.searchDate = {
        startDate: '',
        endDate: ''
      },
        this.yearValue = '',
        this.quarterValue = '',
        this.date = ''
    }
  }
}
</script>

<style lang="scss" scoped>
.search-row {
  padding: 0 20px;
  height: 60px !important;
  min-height: 60px !important;
  background: #fff;
  // line-height: 60px;

  .search-box {
    display: flex;
    align-items: center;
    flex-wrap: nowrap;
    height: 100%;

    .search-title {
      width: fit-content;
      padding-right: 10px;
    }
    :last-child {
      flex: 1;
    }
  }

  .el-col-4 {
    display: flex;

    align-items: center;
    line-height: 60px;
  }
}

.bbsl-common-page {
  height: 100%;
  background-color: #ebeef4;
  display: flex;
  flex-direction: column;
  row-gap: 10px;
  overflow-y: auto;

  &::-webkit-scrollbar {
    display: none;
  }

  ::v-deep .el-row {
    flex: 1;
    min-height: 350px;

    .el-col {
      height: 100%;

      .module-box {
        height: 100%;
        display: flex;
        flex-direction: column;
        box-sizing: border-box;
        background-color: #fff;
        border-radius: 10px;
        overflow: hidden;
        transition: box-shadow 0.3s;
        box-shadow: rgba(0, 0, 0, 0.05) 0 3px 3px 0;
      }
    }
  }
}
</style>
